<?php

    /* Preview Theme URLs */

    define('_PREVIEW_SUFFIX_', '_preview');
    define('_SP_', '/');
    define('IMAGE_STORAGE', _PS_IMG_DIR_ . _SP_ . 'designer');
    define('IMG_PATH_TOKEN', '../img');

    function isPreviewTheme() {
        $result = Tools::getValue('theme_name', false);
        if ($result) return true;
        return false;
    }

    function getPreviewThemeName() {
        $themeName = Tools::getValue('theme_name', '');
        if (!empty($themeName)) 
            return $themeName . _PREVIEW_SUFFIX_;
        return ''; 
    }

    function getPreviewThemeUrl() {
        return _THEMES_DIR_ . getPreviewThemeName() . _SP_;
    }

    function getPreviewThemeDir() {
        return _PS_ROOT_DIR_ . _SP_ . 'themes' . _SP_ . getPreviewThemeName() . _SP_;
    }

    function getPreviewCssDir() {
        return getPreviewThemeUrl() .  'css' . _SP_;
    }

    function getPreviewImgDir() {
        return getPreviewThemeUrl() .  'img' . _SP_;
    }

    function getPreviewJsDir() {
        return getPreviewThemeUrl() .  'js' . _SP_;
    }

    function getThemeName() {
        return isPreviewTheme() ? getPreviewThemeName() : _THEME_NAME_;
    }

    function getThemeUrl() {
        return isPreviewTheme() ? getPreviewThemeUrl() : _THEME_DIR_;
    }

    function getThemeDir($themeName = '') {
        if (empty($themeName))
            return isPreviewTheme() ? getPreviewThemeDir() : _PS_THEME_DIR_;
            
        return _PS_ALL_THEMES_DIR_ . $themeName;
    }

    function getProjectPath($themeName) {
        return _PS_ALL_THEMES_DIR_ . $themeName . '/project/project.json';
    }
    
    function addThemlerParam(array $params = array(), $route_id = null) {
        $themeParams = array('theme_name');
        if ($route_id && ($route_id == 'AdminLogin')) // added domain parameter to login and redirect to Themler with it 
            $themeParams = array('theme_name', 'domain', 'noCache');
        foreach ($themeParams as $themeParam) {
            if (Tools::getIsset($themeParam)) {
                $tp = array($themeParam => Tools::getValue($themeParam, false));
                $params = $tp + $params;
            }
        }
        return $params;
    }

    function wrapThemlerEdit($display, $moduleInstance, $id_hook) {
        $moduleId = (int)$id_hook.'_module_'.(int)$moduleInstance->id.'_moduleName_'.str_replace('_', '-', Tools::safeOutput($moduleInstance->name));
        if (empty($display) && nonDisplayableModule($moduleInstance->name)) // TODO: non-displayable modules for a while
            return;// '<div data-block-id="hook_'.$moduleId.'">&nbsp;</div>';
        return preg_replace('~<(.*?id=[\'"])(.*?)([\'"])~',
                            '<$1$2$3 data-block-id="hook_'.$moduleId.'$3', $display, 1);
    }
    
    function getModulesCount($hook_name, $module_list) {
        $count = count($module_list);
        if ($hook_name == 'displayFooter') {
            $arrIt = new RecursiveArrayIterator($module_list);
            foreach ($arrIt as $sub)
                if (isset($sub['module']) && nonDisplayableModule($sub['module']))
                    $count--;
        }
        return $count;
    }

    function addBootstrapColumn($display, $moduleInstance, $hook_name, $count, $current_index) {
        if ($hook_name != 'displayFooter' || (empty($display) && nonDisplayableModule($moduleInstance->name)))
            return $display;

        $bootstrap_column_count = 24;
        $width = (int)round ($bootstrap_column_count/$count);
        if ($current_index == $count-1)
            $width = (int)($bootstrap_column_count - $width*($count-1));
         // TODO: check drag & drop
        return '<div class="col-md-' . $width . '">'.$display.'</div>';
        /*return preg_replace('/<(.*?class=[\'"])(.*?)([\'"])/si',
                            '<$1col-md-' . $width . ' $2$3', $display, 1);*/
    }

    function nonDisplayableModule($moduleName) {
        $nonDisplayableModules = array('blocklayered', 'statsdata', 'themeconfigurator');
        return in_array($moduleName, $nonDisplayableModules);
    }

    function getSliderSettingsName($themeName, $sliderName, $modeName) {
        return $themeName.'__'.$sliderName.'__'.$modeName;
    }

    function getSliderModeVars() {
        $vars = array();
        $sliders = getSliders();
        $modes = getSliderModes();
        foreach (Theme::getAvailable(false) as $themeName) {
            foreach ($sliders as $sliderName => $sliderCaption) {
                foreach ($modes as $modeName => $modeCaption) {
                    $name = getSliderSettingsName($themeName, $sliderName, $modeName);
                    $vars[$themeName][$sliderName][$modeName] = Configuration::get($name);
                }
            }
        }
        return $vars;
    }
    
    function getSliderModes() {
        return array('desktops' => 'Desktops', 'laptops' => 'Laptops', 'tablets' => 'Tablets', 'phones' => 'Phones', 'itemsInRow' => 'Number of products in slide');
    }

    function getSliders() {
        $result = array('newproducts_slider' => 'New products slider', 'bestsellers_slider' => 'Top-sellers slider', 'products_category_slider' => 'Products in the same category slider', 'crosssell_slider' => 'Cross-selling slider', 'featured_slider' => 'Featured products slider on the homepage', 'viewed_slider' => 'Viewed products block slider', 'specials_slider' => 'Specials block slider', 'accessories_slider' => 'Accessories');
        if (version_compare(_PS_VERSION_,'1.6','<'))
            $result['bestsellers_slider_home'] = 'Top-sellers slider on the homepage';
        return $result;
    }